@@ -34,6 +34,17 @@ static JammoSequencer* singinggame_sequencer = NULL; //used for stopping
 static GList* songs = NULL;
 
 
+gboolean singinggame_language_selection_clicked(TangleButton* tanglebutton, gpointer sequencer){
+	clutter_actor_show(jammo_get_actor_by_id("language-selection-view"));
+	clutter_actor_hide(jammo_get_actor_by_id("songselection-view"));
+	return TRUE;
+}
+
+gboolean singinggame_duetto_selection_clicked(TangleButton* tanglebutton, gpointer sequencer){
+	clutter_actor_show(jammo_get_actor_by_id("duetto-selection-view"));
+	clutter_actor_hide(jammo_get_actor_by_id("songselection-view"));
+	return TRUE;
+}
 
 gboolean singinggame_cross_click(TangleButton* tanglebutton, gpointer sequencer){
 /* //Debugging
@@ -70,8 +81,7 @@ ClutterActor* singinggame_add_cursor(ClutterColor* color, JammoSequencer* sequen
 		}
 	else
 		{
-		texture_image = clutter_texture_new();
-		clutter_texture_set_from_file (CLUTTER_TEXTURE (texture_image), filepath1, NULL);
+		texture_image = tangle_texture_new(filepath1);
 		}
 	g_free(filepath1);
 	
@@ -296,11 +306,11 @@ void singinggame_start_songselection(){
 	tangle_button_set_normal_background_actor(TANGLE_BUTTON(button), NULL);
 
 	//And put new
-	texture =  clutter_texture_new_from_file(new_name, NULL);
+	texture =  tangle_texture_new(new_name);
 	if (texture==NULL) {
 		g_free(new_name);
 		gchar *new_name = g_strdup_printf("%s/language_icon.png", DATA_DIR); //Default icon
-		texture =  clutter_texture_new_from_file(new_name, NULL);
+		texture =  tangle_texture_new(new_name);
 	}
 	tangle_button_set_normal_background_actor(TANGLE_BUTTON(button), texture);
 
@@ -423,20 +433,26 @@ void singinggame_start_songselection(){
 		column_counter++;
 		}
 
-	//Height of the scroller widget is 480, and we should not put smaller in it.
-	if (height_of_container<480)
-		height_of_container=480.0;
+	gchar* mentor_speech;
+
+	TangleLayout* layout = tangle_widget_get_layout(TANGLE_WIDGET(container));
+	GList* trick_list = tangle_layout_get_tricks(layout);
+	ClutterActor* trick = trick_list->data;
+
+	if (height_of_container>480) { //tell more instructions ( about scrolling )
+			g_object_set(trick,"axis",TANGLE_SCROLL_Y_AXIS,NULL);
+			mentor_speech="songselection_welcome.spx songselection_welcome_advanced.spx";
+		}
+	else {
+		g_object_set(trick,"axis",TANGLE_SCROLL_NO_AXIS,NULL);
+		mentor_speech="songselection_welcome.spx";
+	}
+	g_list_free(trick_list);
 
 	//printf("height_of_container:%f\n",height_of_container);
-	clutter_actor_set_size(container, 672.0, height_of_container);
+	clutter_actor_set_size(container, 672.0, 480.0);
+	jammo_mentor_speak_once(jammo_mentor_get_default(),mentor_speech);
 
-	//Say this regardless of skill level
-	jammo_mentor_speak_once(jammo_mentor_get_default(),"songselection_welcome.spx");
-
-	if (height_of_container>480) //tell more instructions ( about scrolling )
-		{ 
-			jammo_mentor_speak_once(jammo_mentor_get_default(),"songselection_welcome_advanced.spx");
-		}
 
 	if (chum_get_duetto())
 		jammo_mentor_set_idle_speech(jammo_mentor_get_default(),"songselection_idle.spx songselection_idle_vocal.spx");
@@ -458,10 +474,13 @@ static void mentor_say_what_is_selected(TangleActor *actor, ClutterActorBox *arg
 	g_signal_handler_disconnect (actor,handler_for_mentor_say_selected);
 }
 
-void singinggame_duetto_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	ClutterActor* ct =CLUTTER_ACTOR(source);
+gboolean singinggame_duetto_clicked (TangleActor* actor, gpointer data) {
+	ClutterActor* ct =CLUTTER_ACTOR(actor);
 	const gchar* name = clutter_actor_get_name(ct);
 
+	clutter_actor_hide(jammo_get_actor_by_id("duetto-selection-view"));
+	clutter_actor_show(jammo_get_actor_by_id("songselection-view"));
+
 	gchar* message = g_strdup_printf("%s clicked",name);
 	cem_add_to_log(message,J_LOG_USER_ACTION);
 	g_free(message);
@@ -471,7 +490,7 @@ void singinggame_duetto_clicked(TangleAction *action, GObject *source, const gch
 
 	if (strcmp(name,"cancel")==0) {
 		tangle_button_set_selected(tanglebutton,!tangle_button_get_selected(tanglebutton));
-		return;
+		return TRUE;
 	}
 
 	if (strcmp(name,"duetto")==0)
@@ -488,21 +507,25 @@ void singinggame_duetto_clicked(TangleAction *action, GObject *source, const gch
 	name_for_mentor =  g_strdup_printf("%s", name);
 	handler_for_mentor_say_selected=g_signal_connect_data(view, "show-completed", G_CALLBACK(mentor_say_what_is_selected),
                                                                   (gpointer)name_for_mentor, (GClosureNotify) g_free,0);
+
+	return TRUE;
 }
 
 
-
-void singinggame_language_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	ClutterActor* ct =CLUTTER_ACTOR(source);
+gboolean singinggame_language_clicked (TangleActor* actor, gpointer data) {
+	ClutterActor* ct =CLUTTER_ACTOR(actor);
 	const gchar* name = clutter_actor_get_name(ct);
 
 	gchar* message = g_strdup_printf("Language '%s' clicked",name);
 	cem_add_to_log(message,J_LOG_DEBUG);
 	g_free(message);
 
-	chum_set_selected_language(name);
+
 
 	ClutterActor* view = jammo_get_actor_by_id("songselection-view");
+	if (strcmp(name,"cancel")!=0) {
+
+	chum_set_selected_language(name);
 	/*
 	There aren't substring(begin,end) in g_
 	e.g.:
@@ -518,7 +541,14 @@ void singinggame_language_clicked(TangleAction *action, GObject *source, const g
 	char* name_for_mentor1 = g_strdup(name);
 	name_for_mentor = g_strreverse (g_strndup (g_strreverse(name_for_mentor1),2));
 	g_free(name_for_mentor1);
-	handler_for_mentor_say_selected = g_signal_connect(view, "show-completed", G_CALLBACK(mentor_say_what_is_selected), (gpointer)name_for_mentor);
+	handler_for_mentor_say_selected = g_signal_connect_data(view, "show-completed", G_CALLBACK(mentor_say_what_is_selected),
+                                                                     (gpointer)name_for_mentor, (GClosureNotify) g_free,0);
+	}
+
+	clutter_actor_hide(jammo_get_actor_by_id("language-selection-view"));
+	clutter_actor_show(view);
+
+	return TRUE;
 }
 
 
