@@ -38,7 +38,7 @@ static void animate_icon_to_cupboard(JammoMentor* mentor, const gchar* speech, g
 		return;
 	int x_for_cupboard = 510;
 	//Cupboard itself
-	ClutterActor* cupboard = clutter_texture_new_from_file("/opt/jammo/cupboard.png", NULL);
+	ClutterActor* cupboard = tangle_texture_new("/opt/jammo/cupboard.png");
 	clutter_actor_set_x(cupboard,x_for_cupboard);
 	clutter_actor_set_y(cupboard,0);
 	TangleWidget* view=TANGLE_WIDGET(clutter_actor_get_parent(CLUTTER_ACTOR(button)));
@@ -47,7 +47,7 @@ static void animate_icon_to_cupboard(JammoMentor* mentor, const gchar* speech, g
 	tangle_widget_add(view, cupboard, NULL);
 
 	//Left door. this will be closed
-	ClutterActor* cupboard_left = clutter_texture_new_from_file("/opt/jammo/cupboard_leftdoor.png", NULL);
+	ClutterActor* cupboard_left = tangle_texture_new("/opt/jammo/cupboard_leftdoor.png");
 	clutter_actor_set_x(cupboard_left,x_for_cupboard);
 	clutter_actor_set_y(cupboard_left,60);
 	tangle_widget_add(TANGLE_WIDGET(clutter_actor_get_parent(CLUTTER_ACTOR(button))), cupboard_left, NULL);
@@ -56,7 +56,7 @@ static void animate_icon_to_cupboard(JammoMentor* mentor, const gchar* speech, g
 	clutter_actor_raise_top(CLUTTER_ACTOR(button));
 
 	//Right door. This will be animated. This will be topmost actor
-	ClutterActor* cupboard_right = clutter_texture_new_from_file("/opt/jammo/cupboard_rightdoor.png", NULL);
+	ClutterActor* cupboard_right = tangle_texture_new("/opt/jammo/cupboard_rightdoor.png");
 	clutter_actor_set_anchor_point(cupboard_right, clutter_actor_get_width(cupboard_right), 0.0);  //anchor is on right side
 	clutter_actor_set_x(cupboard_right,x_for_cupboard+clutter_actor_get_width(cupboard_left)+clutter_actor_get_width(cupboard_right));
 	clutter_actor_set_y(cupboard_right,60);
@@ -201,7 +201,7 @@ static void create_samplebutton(gchar* themename, gchar* variation, gchar* image
 		gchar* filename_for_icon_texture;
 		filename_for_icon_texture = tangle_lookup_filename(full_image);
 
-		ClutterActor* icon_button = tangle_button_new_with_background_actor(clutter_texture_new_from_file(filename_for_icon_texture, NULL));
+		ClutterActor* icon_button = tangle_button_new_with_background_actor(tangle_texture_new(filename_for_icon_texture));
 		g_free(filename_for_icon_texture);
 
 		gchar* name_for_callback = g_strdup_printf("%s",full_image);
@@ -288,7 +288,7 @@ static ClutterActor* create_soundfamily_button(jammo_theme* theme, const gchar*
 	}
 
 	gchar* filename = g_strdup_printf("%s/%s/advanced/%s", THEMES_DIR, theme->name,button_name);
-	ClutterActor *menu_button =  tangle_button_new_with_background_actor(clutter_texture_new_from_file(filename, NULL));
+	ClutterActor *menu_button =  tangle_button_new_with_background_actor(tangle_texture_new(filename));
 	g_free(filename);
 
 	g_object_set(menu_button, "x",x, "y", y, NULL);
@@ -351,26 +351,26 @@ static int create_backing_track_color_coding(const gchar* color_coding, gfloat s
 
 static void on_cursor_notify_x(GObject* object, GParamSpec* param_spec, gpointer user_data) {
 	TangleVault* vault;
-	TangleScrollingActor* scrolling_actor;
+	TangleScrollAction* scroll_action;
 	JammoCursor* cursor;
 	gfloat x, visible, offset, max;
 
 	vault = TANGLE_VAULT(user_data);
-	tangle_vault_get(vault, 2, TANGLE_TYPE_SCROLLING_ACTOR, &scrolling_actor, JAMMO_TYPE_CURSOR, &cursor);
+	tangle_vault_get(vault, 2, TANGLE_TYPE_SCROLL_ACTION, &scroll_action, JAMMO_TYPE_CURSOR, &cursor);
 	g_object_get(object, "x", &x, NULL);
-	g_object_get(scrolling_actor, "width", &visible, "scrolling-offset-x", &offset, "scrolling-width", &max, NULL);
+	g_object_get(scroll_action, "page-length-x", &visible, "offset-x", &offset, "max-offset-x", &max, NULL);
 	if (x < offset) {
 		offset = x - visible + 80.0;
 		if (offset < 0.0) {
 			offset = 0.0;
 		}
-		clutter_actor_animate(CLUTTER_ACTOR(scrolling_actor), CLUTTER_EASE_IN_OUT_QUAD, 250, "scrolling-offset-x", offset, NULL);
+		tangle_object_animate(G_OBJECT(scroll_action), CLUTTER_EASE_IN_OUT_QUAD, 250, "offset-x", offset, NULL);
 	} else if (x > offset + visible - 80.0) {
 		offset += 160.0;
 		if (offset > max) {
 			offset = max;
 		}
-		clutter_actor_animate(CLUTTER_ACTOR(scrolling_actor), CLUTTER_EASE_IN_OUT_QUAD, 250, "scrolling-offset-x", offset, NULL);
+		tangle_object_animate(G_OBJECT(scroll_action), CLUTTER_EASE_IN_OUT_QUAD, 250, "offset-x", offset, NULL);
 	}
 }
 
@@ -790,8 +790,7 @@ if (use_two_tracks) y_offset=80;
 
 
 	//Container for tracks (one or two) and backing_track
-	ClutterActor *container_for_tracks =  tangle_widget_new();
-	//TODO: USE jammo_get_actor_by_id("composition_game_container_for_tracks");
+	ClutterActor* container_for_tracks = jammo_get_actor_by_id("composition_game_container_for_tracks");
 
 
 	ClutterActor *container_for_backingtrack_blocks = tangle_widget_new();
@@ -872,12 +871,10 @@ if (use_two_tracks) y_offset=80;
 	theme->upper_track_view = JAMMO_EDITING_TRACK_VIEW(track_view2); //This is needed when loading/saving
 	}
 
-	//Scrolling area for track (or tracks)
-	ClutterActor* scrolling_actor;
-	scrolling_actor = tangle_scrolling_actor_new(container_for_tracks);
-	clutter_actor_set_position(scrolling_actor, 0.0, 360.0-y_offset);
-	clutter_actor_set_size(scrolling_actor, 800.0, 120.0+y_offset);
-	clutter_container_add_actor(CLUTTER_CONTAINER(view), scrolling_actor);
+	//tune size and position
+	clutter_actor_set_position(container_for_tracks, 0.0, 360.0-y_offset);
+	clutter_actor_set_size(container_for_tracks, 800.0, 120.0+y_offset);
+
 
 	//Logging activity:
 	clutter_actor_set_name(CLUTTER_ACTOR(theme->bottom_track_view),"Bottom");
@@ -903,9 +900,10 @@ if (use_two_tracks) y_offset=80;
 	clutter_actor_set_size(cursor, number_of_slots*WIDTH_OF_SLOT, 80.0);
 	clutter_container_add_actor(CLUTTER_CONTAINER(container_for_tracks), cursor);
 
+	ClutterAction* scroll_action = tangle_actor_get_action_by_type(container_for_tracks,TANGLE_TYPE_SCROLL_ACTION);
 	TangleVault* vault;
 
-	vault = tangle_vault_new(2, TANGLE_TYPE_SCROLLING_ACTOR, scrolling_actor, JAMMO_TYPE_CURSOR, cursor);
+	vault = tangle_vault_new(2, TANGLE_TYPE_SCROLL_ACTION, scroll_action, JAMMO_TYPE_CURSOR, cursor);
 	tangle_signal_connect_vault(texture, "notify::x", G_CALLBACK(on_cursor_notify_x), vault); //FIXME: this is not free'ed!
 
 	//Advanced-game: there are containers for samplebuttons, do not start hidden animations.
@@ -928,8 +926,8 @@ void delete_theme(jammo_theme* theme){
 		clutter_actor_destroy(theme->save_menu_container);
 	}
 	//Free contents of tracks
-	//clutter_container_foreach(CLUTTER_CONTAINER(jammo_get_actor_by_id("composition_game_container_for_tracks")), CLUTTER_CALLBACK(clutter_actor_hide), NULL);
-	//clutter_container_foreach(CLUTTER_CONTAINER(jammo_get_actor_by_id("composition_game_container_for_tracks")), CLUTTER_CALLBACK(clutter_actor_destroy), NULL);
+	clutter_container_foreach(CLUTTER_CONTAINER(jammo_get_actor_by_id("composition_game_container_for_tracks")), CLUTTER_CALLBACK(clutter_actor_hide), NULL);
+	clutter_container_foreach(CLUTTER_CONTAINER(jammo_get_actor_by_id("composition_game_container_for_tracks")), CLUTTER_CALLBACK(clutter_actor_destroy), NULL);
 
 	//Remove set of samplebuttons and all track_views and scrolling-actors etc.
 	clutter_actor_destroy(theme->container);
