@@ -33,16 +33,18 @@ void start_helpdesk(void)
 	helpdesk_show_helpdesk_view();
 }
 
-void helpdesk_goto_communitymenu(TangleButton *tanglebutton, gpointer none)
+gboolean helpdesk_goto_communitymenu(TangleButton *tanglebutton, gpointer none)
 {
 	end_helpdesk();
 	start_communitymenu();
+	return TRUE;
 }
 
-void helpdesk_goto_startmenu(TangleButton *tanglebutton, gpointer none)
+gboolean helpdesk_goto_startmenu(TangleButton *tanglebutton, gpointer none)
 {
 	end_helpdesk();
 	startmenu_goto_startmenu(tanglebutton, none);
+	return TRUE;
 }
 
 gboolean helpdesk_mentor_clicked (TangleButton *tanglebutton, gpointer data)   
@@ -71,23 +73,18 @@ void end_helpdesk(void)
 
 GList* helpdesk_get_number_of_questions(void)
 {
+	GList *l = 0; //Iterator
 	GList *temp = 0;
 
 	helpdesk_messages = g_list_first(helpdesk_messages);
 
-	int index = 0;
+	int index = -1;
 
 	if(g_list_length(helpdesk_messages) != 0)
 	{
-		message *temp_msg = helpdesk_messages->data;
-
-		temp = g_list_append(temp, (gpointer)temp_msg);
-
-		while(helpdesk_messages->next != NULL)
+		for(l = helpdesk_messages; l; l = l->next)
 		{
-			helpdesk_messages = helpdesk_messages->next;
-
-			message *temp_msg = helpdesk_messages->data;
+			message *temp_msg = l->data;
 
 			if(temp_msg->index > index) 
 			{
@@ -95,11 +92,11 @@ GList* helpdesk_get_number_of_questions(void)
 				temp = g_list_append(temp, (gpointer)temp_msg);
 			}
 		}
+
 		g_list_first(temp);
 		return temp;
 	}
-	else
-	return NULL;
+	else	return NULL;
 }
 
 void helpdesk_show_helpdesk_view(void)
@@ -159,8 +156,7 @@ void helpdesk_show_question_view(ClutterActor *actor)
 	start_thread_view(helpdesk_messages, "helpdesk", NULL, selectedQuestion);
 }
 
-void helpdesk_show_addquestion_view(void)
-{
+gboolean helpdesk_show_addquestion_view(TangleActor* actor, gpointer data) {
 	cem_add_to_log(_("Starting AddQuestion View"), J_LOG_DEBUG);
 
 	clear_container(questionslist.list);
@@ -191,6 +187,8 @@ void helpdesk_show_addquestion_view(void)
 	}
 
 	else 	puts("can't find 'helpdesk-addquestion-view' ");
+
+	return TRUE;
 }
 
 void helpdesk_add_question(void)
@@ -239,15 +237,26 @@ void helpdesk_add_question(void)
 	helpdesk_show_helpdesk_view();
 }
 
+gboolean helpdesk_goto_helpdesk_clicked(TangleActor *actor, gpointer data){
+	helpdesk_show_helpdesk_view();
+	return TRUE;
+}
+
+gboolean helpdesk_add_question_clicked(TangleActor *actor, gpointer data){
+	helpdesk_add_question();
+	return TRUE;
+}
+
+
 gboolean helpdesk_add_question_to_list(gpointer data, guint user_id)
 {	
 	ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
-	ClutterActor *colorbar = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar13.png",NULL);
+	ClutterActor *colorbar = tangle_texture_new("/opt/jammo/communitymenu/colorbar13.png");
 	ClutterActor *avatarBackground = clutter_group_new();
 	ClutterActor *composer = tangle_button_new_with_background_actor(avatarBackground);
-	ClutterActor *commentButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
-					"communitymenu/community_comment_icon.png", NULL));
-	clutter_container_add_actor(CLUTTER_CONTAINER(avatarBackground), clutter_texture_new_from_file("/opt/jammo/communitymenu/community_avatarbackground_small.png", NULL));
+	ClutterActor *commentButton = tangle_button_new_with_background_actor(tangle_texture_new(
+					"communitymenu/community_comment_icon.png"));
+	clutter_container_add_actor(CLUTTER_CONTAINER(avatarBackground), tangle_texture_new("/opt/jammo/communitymenu/community_avatarbackground_small.png"));
 
 	message *msg = data;
 
@@ -307,19 +316,18 @@ gboolean helpdesk_add_question_to_list(gpointer data, guint user_id)
 void helpdesk_find_selected_actor(ClutterActor *actor)
 {
 	GList *children = clutter_container_get_children(questionslist.list); //Get list of actors
+	GList *l; //Iterator
 
 	int index = 0;
-	
-	while(children != NULL)
+
+	for(l = children; l; l = l->next)
 	{
-		if(actor == children->data)
+		if(actor == l->data)
 		{
 			selectedQuestion = index;
 			break;
 		}
 
-		children = children->next;
-
 		index++;
 	}
 
