@@ -254,12 +254,14 @@ void instrument_key_interaction_notify (GObject *object, GParamSpec *pspec, gpoi
 
 }
 
-void instrument_goeditor_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+gboolean instrument_goeditor_clicked (TangleActor* actor, gpointer data){
 	cem_add_to_log("GoTo midi-editor pressed",J_LOG_USER_ACTION);
 	end_jamming();
 
 	//start editor
 	midi_editor_start_with_miditrack_view(static_jammo_miditrack_view, static_sequencer);
+
+	return TRUE;
 }
 
 //////////////////////////
@@ -314,8 +316,9 @@ gboolean instrument_gui_slider_handler (ClutterActor *actor, ClutterEvent *event
 
 
 //TODO
-void instrument_metronome_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+gboolean instrument_metronome_clicked (TangleActor* actor, gpointer data){
 	cem_add_to_log("Metronome-button on virtual-instrument pressed (doesn't do anything yet)",J_LOG_USER_ACTION);
+	return FALSE;
 }
 
 
@@ -340,23 +343,12 @@ static void end_jamming() {
 
 
 //TODO
-void instrument_mentor_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+gboolean  instrument_mentor_clicked (TangleActor* actor, gpointer data) {
 	cem_add_to_log("Mentor-button on virtual-instrument pressed (doesn't do anything yet)",J_LOG_USER_ACTION);
+	return FALSE;
 }
 
-/*
-//TODO
-void instrument_gohome_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	printf("instrument_gohome_clicked\n");
-	end_jamming();
-
-	//show sequencer. TODO: go main-menu, not sequencer-view
-	ClutterActor* view = jammo_get_actor_by_id("fullsequencer-view");
-	clutter_actor_show(view);
-}
-*/
-
-void instrument_gosequencer_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+gboolean instrument_gosequencer_clicked (TangleActor* actor, gpointer data){
 	cem_add_to_log("BackToSequencer-button on virtual-instrument pressed",J_LOG_USER_ACTION);
 	end_jamming();
 
@@ -364,9 +356,10 @@ void instrument_gosequencer_clicked (TangleAction *action, GObject *source, cons
 	//ClutterActor* view = jammo_get_actor_by_id("fullsequencer-view");
 	//clutter_actor_show(view);
 	return_to_fullsequencer_gui();
+	return TRUE;
 }
 
-void instrument_play_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+gboolean instrument_play_clicked (TangleActor* actor, gpointer data) {
 	cem_add_to_log("Play-button on virtual-instrument pressed",J_LOG_USER_ACTION);
 	if (recording) {
 		//printf("STOPping recording first\n");
@@ -376,7 +369,7 @@ void instrument_play_clicked (TangleAction *action, GObject *source, const gchar
 	if (playing) {
 		//printf("Already playing -> stop\n");
 		jammo_sequencer_stop (JAMMO_SEQUENCER (static_sequencer));
-		return;
+		return TRUE;
 	}
 
 	//printf("Playing sequencer\n");
@@ -395,15 +388,17 @@ void instrument_play_clicked (TangleAction *action, GObject *source, const gchar
 
 	//Start real-sequencer
 	jammo_sequencer_play(JAMMO_SEQUENCER(static_sequencer));
+
+	return TRUE;
 }
 
 
-void instrument_record_clicked (TangleButton *tanglebutton, gpointer user_data)  {
+gboolean instrument_record_clicked (TangleButton *tanglebutton, gpointer user_data)  {
 	cem_add_to_log("Record-button on virtual-instrument pressed",J_LOG_USER_ACTION);
 	if (recording) {
 		//printf("STOP recording\n");
 		jammo_sequencer_stop (JAMMO_SEQUENCER (static_sequencer));
-		return;
+		return TRUE;
 	}
 
 	if (playing) {
@@ -454,6 +449,7 @@ void instrument_record_clicked (TangleButton *tanglebutton, gpointer user_data)
 	//Now all content in sequencer will play and instrument_track is recording
 	jammo_sequencer_play (JAMMO_SEQUENCER (static_sequencer));
 
+	return TRUE;
 }
 
 //TODO: this signal should be removed when changing view.
