@@ -93,15 +93,15 @@ gboolean add_song_to_list(char* loopName, int numberOfSongs, guint32 user_id){
 	strcpy(params->parent_view, "jammosongs");
 	params->user_id = user_id;
 
-	listImage = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar4.png", NULL); //TODO: image color depends on the song
+	listImage = tangle_texture_new("/opt/jammo/communitymenu/colorbar4.png"); //TODO: image color depends on the song
 
 	listContainer = CLUTTER_CONTAINER(clutter_group_new());
 
-	reviewButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
-			"/opt/jammo/communitymenu/community_comment_icon.png", NULL));
+	reviewButton = tangle_button_new_with_background_actor(tangle_texture_new(
+			"/opt/jammo/communitymenu/community_comment_icon.png"));
 	
 	avatarBackground = clutter_group_new();	
-	clutter_container_add_actor(CLUTTER_CONTAINER(avatarBackground), clutter_texture_new_from_file("/opt/jammo/communitymenu/community_avatarbackground_small.png", NULL));
+	clutter_container_add_actor(CLUTTER_CONTAINER(avatarBackground), tangle_texture_new("/opt/jammo/communitymenu/community_avatarbackground_small.png"));
 	composer = tangle_button_new_with_background_actor(avatarBackground);		
 	
 			
@@ -140,7 +140,7 @@ gboolean add_song_to_list(char* loopName, int numberOfSongs, guint32 user_id){
 	command = g_strdup_printf("ls %s 1> /dev/null 2> /dev/null", labelParams->path);
 	
 	if(system(command) == 0){
-		label = tangle_button_new_with_background_actor(clutter_texture_new_from_file("/opt/jammo/communitymenu/community_cdlabel_small.png", NULL));
+		label = tangle_button_new_with_background_actor(tangle_texture_new("/opt/jammo/communitymenu/community_cdlabel_small.png"));
 		clutter_actor_set_position(label, 500, list.listItemHeight/3);
 		clutter_container_add_actor(listContainer, label);
 	}
@@ -252,7 +252,7 @@ void review_selected_song(ClutterActor *song){
 }
 
 
-void end_jammosongs(TangleButton *tanglebutton, gpointer none){
+gboolean end_jammosongs(TangleButton *tanglebutton, gpointer none){
 
 	community_clear_labelparamslist(labelParamsList);
 
@@ -278,6 +278,7 @@ void end_jammosongs(TangleButton *tanglebutton, gpointer none){
 	else
 	   startmenu_goto_startmenu(tanglebutton, none);
 
+	return TRUE;
 }
 
 
