@@ -65,11 +65,11 @@ void start_jammosounds(){
 
 gboolean add_loop_to_list(char* name, int numberOfLoops){
 
-	ClutterActor* listImage = clutter_texture_new_from_file("/opt/jammo/communitymenu/community_jammosounds_bar.png", NULL);
+	ClutterActor* listImage = tangle_texture_new("/opt/jammo/communitymenu/community_jammosounds_bar.png");
 	ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
-	ClutterActor *importButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
-			"/opt/jammo/communitymenu/community_icon_toloopgame.png", NULL));			
-	ClutterActor *arrowImage = clutter_texture_new_from_file("/opt/jammo/communitymenu/community_rightarrow.png", NULL);
+	ClutterActor *importButton = tangle_button_new_with_background_actor(tangle_texture_new(
+			"/opt/jammo/communitymenu/community_icon_toloopgame.png"));			
+	ClutterActor *arrowImage = tangle_texture_new("/opt/jammo/communitymenu/community_rightarrow.png");
 	ClutterActor *instrument;
 	ClutterActor *text;
 	ClutterActor *loopName;
@@ -86,7 +86,7 @@ gboolean add_loop_to_list(char* name, int numberOfLoops){
 	
 	//TODO: add instrument icon depending on the instrument
 
-	instrument = clutter_texture_new_from_file("/opt/jammo/wheel_game/piano.png", NULL);  
+	instrument = tangle_texture_new("/opt/jammo/wheel_game/piano.png");  
 	clutter_actor_set_position(instrument, 130, 0);
 	clutter_actor_set_height(instrument, listItemHeight);
 	clutter_container_add_actor(listContainer, instrument);
@@ -186,7 +186,7 @@ void import_selected_loop(ClutterActor *loop){
 
 
 
-void end_jammosounds(TangleButton *tanglebutton, gpointer none){
+gboolean end_jammosounds(TangleButton *tanglebutton, gpointer none){
 
 	clear_container(list);
    
@@ -196,6 +196,7 @@ void end_jammosounds(TangleButton *tanglebutton, gpointer none){
 	else
 	   startmenu_goto_startmenu(tanglebutton, none);
 
+	return TRUE;
 }
 
 
