@@ -61,8 +61,7 @@ void start_profile_view(profile_view_params *pvp){
 
 }
 
-
-void end_profile_view(){
+gboolean end_profile_view(TangleActor* actor, gpointer data){
 
 	DESTROY_ACTOR(avatar.body);
 	DESTROY_ACTOR(avatar.hair);
@@ -87,4 +86,6 @@ void end_profile_view(){
 		tangle_actor_hide_animated(TANGLE_ACTOR(jammo_get_actor_by_id("profile-view")));
 		clutter_actor_show(jammo_get_actor_by_id("threads-view"));
 	}		
+
+	return TRUE;
 }
