@@ -42,7 +42,7 @@ View contains three part:
 #include "../file_helper.h"
 
 #include "mysongs.h"
-
+#include "jammo-collaboration-group-composition.h"
 
 /*
 Sequencer and sequencer-track-view-area are defined in json.
@@ -60,7 +60,15 @@ When sequencer starts: it calls load_state_from_file(load_only_backingtrack=TRUE
 JammoSequencer* static_sequencer;
 JammoMetronomeTrack* static_metronome_track;
 
+static JammoCollaborationGroupComposition* static_group_composition = NULL;
 
+JammoCollaborationGroupComposition* sequencer_get_group_composition() {
+	return static_group_composition;
+}
+
+void sequencer_set_group_composition(JammoCollaborationGroupComposition* pc) {
+	static_group_composition=pc;
+}
 
 static void load_state_from_file(gchar* filename, gboolean load_only_backingtrack) {
 
@@ -486,17 +494,18 @@ static void leave_fullsequencer() {
 	current_levelview=NULL;
 }
 
-void fullsequencer_home_clicked (TangleButton* tanglebutton, gpointer none){
+gboolean fullsequencer_home_clicked (TangleButton* tanglebutton, gpointer none){
 	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), "");
 	jammo_mentor_shut_up(jammo_mentor_get_default());
 	leave_fullsequencer();
 	startmenu_goto_startmenu(NULL,NULL);
+	return TRUE;
 }
 
-void fullsequencer_general_tempo_clicked(TangleButton *tanglebutton, gpointer user_data) {
+gboolean fullsequencer_general_tempo_clicked(TangleButton *tanglebutton, gpointer user_data) {
 	const gchar* name=clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton));
 	if (name==NULL)
-		return;
+		return TRUE;
 
 	int new_tempo = 110;
 	if (strncmp(name,"fast",4)==0)
@@ -511,13 +520,14 @@ void fullsequencer_general_tempo_clicked(TangleButton *tanglebutton, gpointer us
 	g_free(message);
 
 	jammo_sequencer_set_tempo(static_sequencer, new_tempo);
+	return TRUE;
 }
 
 
-void fullsequencer_general_pitch_clicked(TangleButton *tanglebutton, gpointer user_data) {
+gboolean fullsequencer_general_pitch_clicked(TangleButton *tanglebutton, gpointer user_data) {
 	const gchar* name=clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton));
 	if (name==NULL)
-		return;
+		return TRUE;
 
 	gchar* new_pitch = "G";
 	if (strncmp(name,"high",4)==0)
@@ -532,6 +542,7 @@ void fullsequencer_general_pitch_clicked(TangleButton *tanglebutton, gpointer us
 	g_free(message);
 
 	jammo_sequencer_set_pitch(static_sequencer, new_pitch);
+	return TRUE;
 }
 
 
@@ -548,7 +559,7 @@ static void on_rendering_stopped(JammoSequencer* sequencer, gpointer none) {
 
 }
 
-void sequencer_render_button_pressed (TangleButton* tanglebutton, gpointer none){
+gboolean sequencer_render_button_pressed (TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log("Render-button pressed",J_LOG_USER_ACTION);
 
 	//If sequencer is playing, use render button as stop-button.
@@ -558,7 +569,7 @@ void sequencer_render_button_pressed (TangleButton* tanglebutton, gpointer none)
 	if (play) {
 		jammo_sequencer_stop(static_sequencer);
 		cem_add_to_log(" Sequencer was playing/rendering -> stop",J_LOG_DEBUG);
-		return;
+		return TRUE;
 	}
 
 	char timestamp [80];
@@ -582,6 +593,7 @@ void sequencer_render_button_pressed (TangleButton* tanglebutton, gpointer none)
 		cem_add_to_log("Can't render audiofile",J_LOG_ERROR);
 
 	g_free(outputFilename);
+	return TRUE;
 }
 
 void sequencer_save_project(){
@@ -596,20 +608,21 @@ void sequencer_save_project(){
 	cem_add_to_log("  Saving ready",J_LOG_INFO);
 }
 
-void sequencer_save_project_button_pressed (TangleButton* tanglebutton, gpointer none){
+gboolean sequencer_save_project_button_pressed (TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log("Saving project file",J_LOG_INFO);
 	sequencer_save_project();
-	return;
+	return TRUE;
 }
 
 
-void sequencer_mysongs_button_pressed (TangleButton* tanglebutton, gpointer none){
+gboolean sequencer_mysongs_button_pressed (TangleButton* tanglebutton, gpointer none){
 	leave_fullsequencer();
 	start_mysongs();
+	return TRUE;
 }
 
 
-void fullsequencer_metronome_clicked (TangleButton* tanglebutton, gpointer none){
+gboolean fullsequencer_metronome_clicked (TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log("Metronome pressed",J_LOG_USER_ACTION);
 
 	if (static_metronome_track==NULL) {
@@ -622,4 +635,6 @@ void fullsequencer_metronome_clicked (TangleButton* tanglebutton, gpointer none)
 	}
 	else
 		jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(static_metronome_track), !tangle_button_get_selected(tanglebutton));
+
+	return TRUE;
 }
