@@ -160,7 +160,7 @@ static void on_sequencer_stopped(JammoSequencer* sequencer, gpointer data) {
 /*
  * plays all samples from centerline of loop rolls
  */
-void fullsequencer_loop_play_all_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+gboolean fullsequencer_loop_play_all_clicked (TangleActor *actor, gpointer data) {
 	cem_add_to_log("fullsequencer_play_all_loops-clicked",J_LOG_USER_ACTION);
 
 	//get_centermost_sample_from_loop_roll can return NULL (in error cases)
@@ -197,6 +197,8 @@ void fullsequencer_loop_play_all_clicked (TangleAction *action, GObject *source,
 
 	g_signal_connect(ad_hoc_sequencer, "stopped", G_CALLBACK(on_sequencer_stopped), NULL);
 	jammo_sequencer_play(ad_hoc_sequencer);
+
+	return TRUE;
 }
 
 
@@ -242,7 +244,7 @@ static void rotate_to_place(ClutterActor* wheel, gint target_slot) {
 /*
 cannot_fail_lists is index for corresponding lists.
 */
-void fullsequencer_loop_cannot_fail_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+gboolean fullsequencer_loop_cannot_fail_clicked (TangleActor* actor, gpointer data) {
 	cem_add_to_log("fullsequencer_loop_cannot_fail_clicked-clicked",J_LOG_USER_ACTION);
 
 	GRand *random_gen = g_rand_new();
@@ -263,6 +265,8 @@ void fullsequencer_loop_cannot_fail_clicked (TangleAction *action, GObject *sour
 	rotate_to_place(melodical_sample_looper, combo.m);
 	rotate_to_place(harmonical_sample_looper, combo.h);
 	rotate_to_place(effect_sample_looper, combo.e);
+
+	return TRUE;
 }
 
 void sequencer_loop_randomize_wheels(){
@@ -282,26 +286,16 @@ void sequencer_loop_randomize_wheels(){
 }
 
 //This is just random.
-void fullsequencer_loop_crazy_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+gboolean fullsequencer_loop_crazy_clicked (TangleActor *actor, gpointer data){
 	cem_add_to_log("fullsequencer_loop_crazy_clicked-clicked",J_LOG_USER_ACTION);
 	sequencer_loop_randomize_wheels();
+	return TRUE;
 }
 
 
 //////////////////////////////////////
 
 
-/*
-DEPRECATED
-Bottom of the loop-view there are dropping-area, and when samplebutton is dragged here, view is changed.
-*/
-gboolean sequencer_drag_begin(TangleDropAction* drop_action, TangleDragAction* drag_action){
-	cem_add_to_log("jammo_sample_button dragged from wheel to bottom of the screen",J_LOG_USER_ACTION);
-	sequencer_change_to_sequencer_view(NULL,NULL);
-	
-	return FALSE;
-}
-
 static void sample_button_drag_begin(JammoSampleButton* sample_button, gpointer data) {
 	cem_add_to_log("jammo_sample_button from wheel drag-begin",J_LOG_USER_ACTION);
 	sequencer_change_to_sequencer_view(NULL,NULL);
