@@ -717,18 +717,12 @@ static gboolean check_if_overlapping(JammoEditingTrackView* track_view, ClutterA
 	return actor != NULL;
 }
 
-static gboolean on_drag_begin_or_motion(TangleDropAction* drop_action, TangleDragAction* drag_action, gpointer user_data) {
+static gboolean is_droppable(JammoEditingTrackView* track_view, TangleDragAction* drag_action, guint* slot_return, guint* n_slots_return) {
 	gboolean droppable = FALSE;
-	JammoEditingTrackView* track_view;
 	ClutterActor* meta_actor;
 	ClutterActor* drag_actor;
 	gfloat x, y, w, h;
 	gfloat center_x, center_y;
-	guint slot = 0;
-	guint n_slots = 0;
-	gfloat start;
-
-	track_view = JAMMO_EDITING_TRACK_VIEW(user_data);
 	
 	meta_actor = clutter_actor_meta_get_actor(CLUTTER_ACTOR_META(drag_action));
 	drag_actor = tangle_drag_action_get_drag_actor(drag_action);;
@@ -739,20 +733,31 @@ static gboolean on_drag_begin_or_motion(TangleDropAction* drop_action, TangleDra
 
 			guint64 duration_of_one_slot= track_view->priv->slot_duration;
 			guint64 duration_of_sample = jammo_sample_get_duration(jammo_sample_button_get_sample(JAMMO_SAMPLE_BUTTON(meta_actor)));
-			n_slots = (guint) ((double)duration_of_sample / (double) duration_of_one_slot + 0.5);
+			*n_slots_return = (guint) ((double)duration_of_sample / (double) duration_of_one_slot + 0.5);
 
-			center_x -= (n_slots - 1) * track_view->priv->real_slot_width / 2;
-			slot = center_x / track_view->priv->real_slot_width;
+			center_x -= (*n_slots_return - 1) * track_view->priv->real_slot_width / 2;
+			*slot_return = center_x / track_view->priv->real_slot_width;
 
-			if (slot >= track_view->priv->disabled_slots_begin &&
-			    slot + n_slots - 1 < track_view->priv->n_slots - track_view->priv->disabled_slots_end &&
-			    !check_if_overlapping(track_view, meta_actor, slot)) {
+			if (*slot_return >= track_view->priv->disabled_slots_begin &&
+			    *slot_return + *n_slots_return - 1 < track_view->priv->n_slots - track_view->priv->disabled_slots_end &&
+			    !check_if_overlapping(track_view, meta_actor, *slot_return)) {
 				droppable = TRUE;
 			}
 		}
 	}
 	
-	if (droppable) {
+	return droppable;	
+}
+
+static gboolean on_drag_begin_or_motion(TangleDropAction* drop_action, TangleDragAction* drag_action, gpointer user_data) {
+	JammoEditingTrackView* track_view;
+	guint slot, n_slots;
+	gfloat start;
+
+	track_view = JAMMO_EDITING_TRACK_VIEW(user_data);
+	
+	
+	if (is_droppable(track_view, drag_action, &slot, &n_slots)) {
 		start = slot * track_view->priv->real_slot_width;
 		if (start != track_view->priv->hilighted_start) {
 			track_view->priv->hilighted_start = start;
@@ -764,17 +769,18 @@ static gboolean on_drag_begin_or_motion(TangleDropAction* drop_action, TangleDra
 		clutter_actor_queue_redraw(CLUTTER_ACTOR(track_view));
 	}
 	    		
-	return !droppable;
+	return FALSE;
 }
 
 static gboolean on_drag_end(TangleDropAction* drop_action, TangleDragAction* drag_action, gpointer user_data) {	
 	JammoEditingTrackView* track_view;
+	guint slot, n_slots;
 
 	track_view = JAMMO_EDITING_TRACK_VIEW(user_data);
 
 	track_view->priv->hilighted_start = track_view->priv->hilighted_end = -1.0;
 
-	return FALSE;
+	return !is_droppable(track_view, drag_action, &slot, &n_slots);
 }
 
 static void on_dropped(TangleDropAction* drop_action, TangleDragAction* drag_action, gpointer user_data) {
