@@ -21,8 +21,7 @@ G_DEFINE_TYPE_WITH_CODE(JammoGameLevel, jammo_game_level, TANGLE_TYPE_OBJECT,
 enum {
 	PROP_0,
 	PROP_TASKS_COMPLETED,
-	PROP_TASKS_TO_COMPLETE,
-	PROP_COMPLETED_ACTION
+	PROP_TASKS_TO_COMPLETE
 };
 
 enum {
@@ -37,7 +36,6 @@ typedef struct _TaskData {
 
 struct _JammoGameLevelPrivate {
 	GList* task_datas;
-	TangleAction* completed_action;
 	
 	TaskData* active_task_data;
 	JammoGameTask* active_task;
@@ -221,27 +219,14 @@ void jammo_game_level_stop_task(JammoGameLevel* game_level) {
 }
 
 static void jammo_game_level_completed(JammoGameLevel* game_level) {
-	if (game_level->priv->completed_action) {
-		tangle_action_execute_full_list(game_level->priv->completed_action, G_OBJECT(game_level), "completed", NULL);
-	}
 }
 
-#define SET_ACTION(a) \
-	if (game_level->priv->a) { \
-		g_object_unref(game_level->priv->a); \
-	} \
-	game_level->priv->a = TANGLE_ACTION(g_value_get_object(value)); \
-	g_object_ref(game_level->priv->a);
-
 static void jammo_game_level_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
 	JammoGameLevel* game_level;
 	
 	game_level = JAMMO_GAME_LEVEL(object);
 
 	switch (prop_id) {
-		case PROP_COMPLETED_ACTION:
-			SET_ACTION(completed_action);
-			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 			break;
@@ -254,15 +239,9 @@ static void jammo_game_level_get_property(GObject* object, guint prop_id, GValue
 	game_level = JAMMO_GAME_LEVEL(object);
 
         switch (prop_id) {
-		case PROP_TASKS_COMPLETED:
-			g_value_set_uint(value, jammo_game_level_get_tasks_completed(game_level));
-			break;
 		case PROP_TASKS_TO_COMPLETE:
 			g_value_set_uint(value, jammo_game_level_get_tasks_to_complete(game_level));
 			break;
-		case PROP_COMPLETED_ACTION:
-			g_value_set_object(value, game_level->priv->completed_action);
-			break;
 	        default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		        break;
@@ -317,17 +296,6 @@ static void jammo_game_level_class_init(JammoGameLevelClass* game_level_class) {
 	                                "The number of completed tasks",
 	                                0, G_MAXUINT, 0,
 	                                G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-	/**
-	 * JammoGameLevel:completed-action:
-	 *
-	 * The action that correspond to the completed signal.
-	 */
-	g_object_class_install_property(gobject_class, PROP_COMPLETED_ACTION,
-	                                g_param_spec_object("completed-action",
-	                                "Completed action",
-	                                "The action that correspond to the completed signal",
-	                                TANGLE_TYPE_ACTION,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
 	/**
 	 * JammoGameLevel::completed:
