@@ -21,11 +21,7 @@ enum {
 	PROP_0,
 	PROP_VIEW,
 	PROP_ACTS_TO_COMPLETE,
-	PROP_ACTS_COMPLETED,
-	PROP_STARTED_ACTION,
-	PROP_ACT_COMPLETED_ACTION,
-	PROP_ACT_REDONE_ACTION,
-	PROP_COMPLETED_ACTION
+	PROP_ACTS_COMPLETED
 };
 
 enum {
@@ -47,11 +43,6 @@ struct _JammoGameTaskPrivate {
 	GList* acts;
 	guint acts_to_complete;
 	
-	TangleAction* started_action;
-	TangleAction* act_completed_action;
-	TangleAction* act_redone_action;
-	TangleAction* completed_action;
-	
 	GSList* enabled_actors;
 	GSList* disabled_actors;
 	
@@ -211,35 +202,16 @@ guint jammo_game_task_get_acts_completed(JammoGameTask* task) {
 	return number_of_completed_acts;
 }
 
-#define SET_ACTION(a) \
-	if (task->priv->a) { \
-		g_object_unref(task->priv->a); \
-	} \
-	task->priv->a = TANGLE_ACTION(g_value_get_object(value)); \
-	g_object_ref(task->priv->a);
-
 static void jammo_game_task_started(JammoGameTask* task) {
-	if (task->priv->started_action) {
-		tangle_action_execute_full_list(task->priv->started_action, G_OBJECT(task), "started", NULL);
-	}
 }
 
 static void jammo_game_task_act_completed(JammoGameTask* task, const gchar* act_name, guint acts_completed) {
-	if (task->priv->act_completed_action) {
-		tangle_action_execute_full_list(task->priv->act_completed_action, G_OBJECT(task), "act-completed", "act-name", act_name, "acts-completed", acts_completed, NULL);
-	}
 }
 
 static void jammo_game_task_act_redone(JammoGameTask* task, const gchar* act_name, guint acts_completed) {
-	if (task->priv->act_redone_action) {
-		tangle_action_execute_full_list(task->priv->act_redone_action, G_OBJECT(task), "act-redone", "act-name", act_name, "acts-completed", acts_completed, NULL);
-	}
 }
 
 static void jammo_game_task_completed(JammoGameTask* task) {
-	if (task->priv->completed_action) {
-		tangle_action_execute_full_list(task->priv->completed_action, G_OBJECT(task), "completed", NULL);
-	}
 }
 
 static void jammo_game_task_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
@@ -255,18 +227,6 @@ static void jammo_game_task_set_property(GObject* object, guint prop_id, const G
 		case PROP_ACTS_TO_COMPLETE:
 			jammo_game_task_set_acts_to_complete(task, g_value_get_uint(value));
 			break;
-		case PROP_STARTED_ACTION:
-			SET_ACTION(started_action);
-			break;
-		case PROP_ACT_COMPLETED_ACTION:
-			SET_ACTION(act_completed_action);
-			break;
-		case PROP_ACT_REDONE_ACTION:
-			SET_ACTION(act_redone_action);
-			break;
-		case PROP_COMPLETED_ACTION:
-			SET_ACTION(completed_action);
-			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 			break;
@@ -288,18 +248,6 @@ static void jammo_game_task_get_property(GObject* object, guint prop_id, GValue*
 		case PROP_ACTS_COMPLETED:
 			g_value_set_uint(value, jammo_game_task_get_acts_completed(task));
 			break;
-		case PROP_STARTED_ACTION:
-			g_value_set_object(value, task->priv->started_action);
-			break;
-		case PROP_ACT_COMPLETED_ACTION:
-			g_value_set_object(value, task->priv->act_completed_action);
-			break;
-		case PROP_ACT_REDONE_ACTION:
-			g_value_set_object(value, task->priv->act_redone_action);
-			break;
-		case PROP_COMPLETED_ACTION:
-			g_value_set_object(value, task->priv->completed_action);
-			break;
 	        default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		        break;
@@ -360,50 +308,6 @@ static void jammo_game_task_class_init(JammoGameTaskClass* game_class) {
 	                                "The number of completed acts",
 	                                0, G_MAXUINT, 0,
 	                                G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-	/**
-	 * JammoGameTask:started-action:
-	 *
-	 * The action that correspond to the started signal.
-	 */
-	g_object_class_install_property(gobject_class, PROP_STARTED_ACTION,
-	                                g_param_spec_object("started-action",
-	                                "Started action",
-	                                "The action that correspond to the started signal",
-	                                TANGLE_TYPE_ACTION,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-	/**
-	 * JammoGameTask:act-completed-action:
-	 *
-	 * The action that correspond to the act-completed signal.
-	 */
-	g_object_class_install_property(gobject_class, PROP_ACT_COMPLETED_ACTION,
-	                                g_param_spec_object("act-completed-action",
-	                                "Act completed action",
-	                                "The action that correspond to the act-completed signal",
-	                                TANGLE_TYPE_ACTION,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-	/**
-	 * JammoGameTask:act-redone-action:
-	 *
-	 * The action that correspond to the act-redone signal.
-	 */
-	g_object_class_install_property(gobject_class, PROP_ACT_REDONE_ACTION,
-	                                g_param_spec_object("act-redone-action",
-	                                "Act redone action",
-	                                "The action that correspond to the act-redone signal",
-	                                TANGLE_TYPE_ACTION,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-	/**
-	 * JammoGameTask:completed-action:
-	 *
-	 * The action that correspond to the completed signal.
-	 */
-	g_object_class_install_property(gobject_class, PROP_COMPLETED_ACTION,
-	                                g_param_spec_object("completed-action",
-	                                "Completed action",
-	                                "The action that correspond to the completed signal",
-	                                TANGLE_TYPE_ACTION,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
 	/**
 	 * JammoGameTask::started:
