@@ -72,7 +72,7 @@ static guint signals[LAST_SIGNAL] = { 0 };
 static void on_drag_begin(ClutterDragAction* action, ClutterActor* actor, gfloat event_x, gfloat event_y, ClutterModifierType modifiers, gpointer user_data);
 static void on_drag_end(ClutterDragAction* action, ClutterActor* actor, gfloat event_x, gfloat event_y, ClutterModifierType modifiers, gpointer user_data);
 static gboolean on_clicked(TangleButton* button, gpointer user_data);
-static void on_size_change(ClutterTexture* texture, gint width, gint height, gpointer user_data);
+static void on_size_changed(TangleTexture* texture, gint width, gint height, gpointer user_data);
 static void set_sequencer(JammoSampleButton* sample_button, JammoSequencer* sequencer);
 
 ClutterActor* jammo_sample_button_new() {
@@ -135,7 +135,7 @@ void jammo_sample_button_set_image_filename(JammoSampleButton* sample_button, co
 		sample_button->priv->image_filename = g_strdup(image_filename);
 
 		filename = tangle_lookup_filename(image_filename);
-		texture = clutter_texture_new_from_file(filename, NULL);
+		texture = tangle_texture_new(filename);
 		g_free(filename);
 		if (!texture) {
 			g_warning("Could not create a texture from a file '%s', ignored.", image_filename);
@@ -144,7 +144,7 @@ void jammo_sample_button_set_image_filename(JammoSampleButton* sample_button, co
 			sample_button->priv->image_filename = NULL;
 		} else {
 			tangle_button_set_normal_background_actor(TANGLE_BUTTON(sample_button), texture);
-			g_signal_connect(texture, "size-change", G_CALLBACK(on_size_change), sample_button);
+			g_signal_connect(texture, "size-changed", G_CALLBACK(on_size_changed), sample_button);
 		}
 
 		g_object_notify(G_OBJECT(sample_button), "image-filename");
@@ -247,6 +247,8 @@ static void jammo_sample_button_constructed(GObject* object) {
 	
 	tangle_widget_set_prefer_background_size(TANGLE_WIDGET(object), TRUE);
 	g_signal_connect(object, "clicked", G_CALLBACK(on_clicked), NULL);
+
+	G_OBJECT_CLASS(jammo_sample_button_parent_class)->constructed(object);
 }
 
 static void jammo_sample_button_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
@@ -510,6 +512,7 @@ static void on_drag_begin(ClutterDragAction* action, ClutterActor* actor, gfloat
 	sample_button = JAMMO_SAMPLE_BUTTON(user_data);
 
 	sample_button->priv->dragging = TRUE;
+	tangle_button_stop_highlighting(TANGLE_BUTTON(sample_button));
 
 	jammo_sample_stop_all();
 
@@ -554,7 +557,7 @@ static gboolean on_clicked(TangleButton* button, gpointer user_data) {
 	return FALSE;
 }
 
-static void on_size_change(ClutterTexture* texture, gint width, gint height, gpointer user_data) {
+static void on_size_changed(TangleTexture* texture, gint width, gint height, gpointer user_data) {
 	JammoSampleButton* sample_button;
 	
 	sample_button = JAMMO_SAMPLE_BUTTON(user_data);
