@@ -45,8 +45,8 @@ public:
 	// Get id
 	guint32 GetId();
 	
-	gboolean loadEncryptedProfile(gchar* _username);
-	gboolean reloadEncryptedProfile();
+	guint loadEncryptedProfile(gchar* _username);
+	guint reloadEncryptedProfile();
 	gboolean saveEncryptedProfile();
 	gboolean changeLoadedUser(gchar* _username);
 	gboolean deserializeProfile(gchar* _profile);
@@ -226,8 +226,8 @@ void profilemanager_reset_points(ProfileManager* _aManager);
 
 /* For encrypted profile data */
 
-gboolean profilemanager_storage_load_profile(ProfileManager* _aManager, gchar* _username);
-gboolean profilemanager_storage_reload_profile(ProfileManager* _aManager);
+guint profilemanager_storage_load_profile(ProfileManager* _aManager, gchar* _username);
+guint profilemanager_storage_reload_profile(ProfileManager* _aManager);
 gboolean profilemanager_storage_save_profile(ProfileManager* _aManager);
 gboolean profilemanager_storage_change_profile(ProfileManager* _aManager, gchar* _username);
 guchar* profilemanager_storage_get_password_salt(ProfileManager* _aManager);
