@@ -32,6 +32,7 @@ static void empty_callback_midi_list(GObject * game, guint user_id, gint16 instr
 static void empty_callback_slider_event_list(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list){}
 static void empty_callback_group_control(gint type){}
 static void empty_callback_game(GObject * game, gint type, const gchar* song_info){}
+static void empty_callback_game_starter(gpointer data, gint16 track_id){}
 
 // A "singleton" get
 gems_components* gems_get_data()
@@ -60,6 +61,7 @@ gems_components* gems_get_data()
 		gems_data->waiting_for_teacher = FALSE;
 		gems_data->waiting_profile_from_teacher = FALSE;
 		gems_data->username_to_login = NULL;
+		gems_data->username_forced = FALSE;
 	}
 	return gems_data;
 }
@@ -195,9 +197,10 @@ guint gems_get_teacher_profile_request_count()
 	return gems_get_data()->teacher_profile_requests;
 }
 
-void gems_set_login_username(gchar* username)
+void gems_set_login_username(gchar* username, gboolean forced)
 {
 	gems_get_data()->username_to_login = g_strdup(username);
+	gems_get_data()->username_forced = forced;
 }
 
 gchar* gems_get_login_username()
@@ -214,6 +217,11 @@ void gems_clear_login_username()
 	}
 }
 
+gboolean gems_login_username_forced()
+{
+	return gems_get_data()->username_forced;
+}
+
 gboolean gems_teacher_connection_is_connected()
 {
 	if(gems_get_teacher_connection() != NULL)
@@ -324,6 +332,7 @@ void jammo_gems_init(int argc, char* argv[])
 	chum_callback_slider_event_list=empty_callback_slider_event_list;
 	chum_callback_group_control=empty_callback_group_control;
 	chum_callback_game=empty_callback_game;
+	chum_callback_game_starter=empty_callback_game_starter;
 
 	logmsg = g_strdup_printf("jammo_gems_init: done");
 	cem_add_to_log(logmsg,J_LOG_DEBUG);
@@ -1173,6 +1182,9 @@ void gems_set_callback_group_control(void (*func_ptr)(gint type) ) {
 void gems_set_callback_game(void (*func_ptr)(GObject * game, gint type, const gchar* song_info) ) {
 	chum_callback_game=func_ptr;
 }
+void gems_set_callback_game_starter(void (*func_ptr)(gpointer data, gint16 track_id) ) {
+	chum_callback_game_starter=func_ptr;
+}
 
 void gems_debugging_show_jammos()
 {
