@@ -74,6 +74,8 @@ gint gems_security_extract_envelope(gems_connection* element)
 
 gboolean gems_security_init_security(guchar* password, guchar* salt)
 {
+	cem_add_to_log("Security contexts initialization.", J_LOG_DEBUG);
+	
 	if(!password || !salt) return FALSE;
 	
 	gems_components* components = gems_get_data();
@@ -125,7 +127,7 @@ gboolean gems_security_change_password(guchar* password,guchar* salt)
 	// TODO copy previous contexts in case of errors!
 	else
 	{
-		cem_add_to_log("gems_security_change_password() : failure - re-initialize security!", J_LOG_DEBUG);
+		cem_add_to_log("gems_security_change_password() : failure - re-initialize security!", J_LOG_ERROR);
 		return FALSE;
 	}
 }
