@@ -165,7 +165,7 @@ void gems_service_control_handle_set_login(gems_components* data, gems_connectio
 	}
 	else
 	{
-		gems_set_login_username(loginname);
+		gems_set_login_username(loginname,TRUE);
 		cem_add_to_log("gems_service_control_handle_set_login: user logged in, the username will be changed after logout",J_LOG_DEBUG);
 	}
 	g_free(loginname);
