@@ -24,7 +24,7 @@ void gems_service_jammo_process_new(gems_connection* connection)
 	connection->connection_state = JAMMO_CONNECTING;
 	data->connections = g_list_append(data->connections, connection);
 	gchar* logmsg = g_strdup_printf("gems_service_jammo_process_new: Added new");
-	cem_add_to_log(logmsg,J_LOG_DEBUG);
+	cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 	g_free(logmsg);
 }
 
@@ -148,7 +148,7 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 						{
 							logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): error type couldn't be read, bytesread = %d, dataleft = %d",
 								(service == TRUE ? 's' : 'c'), bytesread, dataleft);
-							cem_add_to_log(logmsg,J_LOG_ERROR);
+							cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 							g_free(logmsg);
 							ph_c_connection_disconnect(element->connection);
 							cleanup_required = TRUE;
@@ -171,7 +171,7 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 					{
 						logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): error reading rest of data, error: %d",
 							(service == TRUE ? 's': 'c'),bytesread);
-						cem_add_to_log(logmsg,J_LOG_ERROR);
+						cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 						ph_c_connection_disconnect(element->connection);
 						cleanup_required = TRUE;
@@ -268,7 +268,7 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 						{
 							logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): Invalid service id %d",
 								(service == TRUE ? 's': 'c'), serviceid);
-							cem_add_to_log(logmsg,J_LOG_ERROR);
+							cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 							g_free(logmsg);
 							
 							gems_message* err = gems_create_error_message(ERROR_INVALID_SERVICE_ID_TYPE, JAMMO_SERVICE_ID);
@@ -277,7 +277,7 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 							{
 								logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): cannot write ERROR_INVALID_SERVICE_ID",
 									(service == TRUE ? 's': 'c'));
-								cem_add_to_log(logmsg,J_LOG_ERROR);
+								cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 								g_free(logmsg);
 							}
 							
@@ -292,7 +292,7 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 					default:
 						logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): service id read error(%d)",
 							(service == TRUE ? 's': 'c'),bytesread);
-						cem_add_to_log(logmsg,J_LOG_ERROR);
+						cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 						ph_c_connection_disconnect(element->connection);
 						cleanup_required = TRUE;
@@ -357,22 +357,22 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 				gems_message* msg = gems_create_message_service_jammo(VERSION_REQ);
 				if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),msg) != msg->length)
 				{
-					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): cannot write VERSION_REQ",
-						(service == TRUE ? 's': 'c'));
-					cem_add_to_log(logmsg,J_LOG_ERROR);
+					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): cannot write VERSION_REQ to %s/%u",
+						(service == TRUE ? 's': 'c'), ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
+					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 					success = FALSE;
 				}
 				else
 				{
-					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): wrote bytes: %d [%d|%d|%d]", (service == TRUE ? 's': 'c'),
+					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): wrote bytes: %d [%d|%u|%d]", (service == TRUE ? 's': 'c'),
 						msg->length, ntohs(*(guint16*)&msg->message[0]),ntohl(*(guint32*)&msg->message[2]),ntohs(*(guint16*)&msg->message[6]));
 					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 							
 					element->connection_state = JAMMO_WAITING_VERSION; // Waiting for VERSION_REPLY
-					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): State changed to JAMMO_WAITING_VERSION",
-						(service == TRUE ? 's': 'c'));
+					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): State changed to JAMMO_WAITING_VERSION for %s/%u",
+						(service == TRUE ? 's': 'c'), ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 				}
@@ -391,15 +391,15 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 					gems_message* msg = gems_create_message_service_jammo(CONNECT_REPLY);
 					if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),msg) != msg->length)
 					{
-						logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): cannot write CONNECT_REPLY",
-							(service == TRUE ? 's': 'c'));
-						cem_add_to_log(logmsg,J_LOG_ERROR);
+						logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): cannot write CONNECT_REPLY to %s/%u",
+							(service == TRUE ? 's': 'c'), ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
+						cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 						success = FALSE;
 					}
 					else
 					{
-						logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): wrote bytes: %d [%d|%d|%d]", (service == TRUE ? 's': 'c'),
+						logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): wrote bytes: %d [%d|%u|%d]", (service == TRUE ? 's': 'c'),
 							msg->length, g_ntohs(*(guint16*)&msg->message[0]),g_ntohl(*(guint32*)&msg->message[2]),g_ntohs(*(guint16*)&msg->message[6]));
 						cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
@@ -407,16 +407,16 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 						if(service == TRUE) // Service
 						{
 							element->connection_state = JAMMO_WAITING_REQUEST; // Waiting for VERSION_REQ
-							logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): State changed to JAMMO_WAITING_REQUEST",
-								(service == TRUE ? 's': 'c'));
+							logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): State changed to JAMMO_WAITING_REQUEST for %s/%u",
+								(service == TRUE ? 's': 'c'), ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 							cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 							g_free(logmsg);
 						}
 						else // Client
 						{
 							element->connection_state = JAMMO_CONNECTED_NO_AUTH; // Connected
-							logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): State changed to JAMMO_CONNECTED_NO_AUTH",
-								(service == TRUE ? 's': 'c'));
+							logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): State changed to JAMMO_CONNECTED_NO_AUTH for %s/%u",
+								(service == TRUE ? 's': 'c'), ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 							cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 							g_free(logmsg);
 						}
@@ -428,14 +428,14 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 					gems_message* err = gems_create_error_message(ERROR_VERSION_MISMATCH_TYPE, JAMMO_SERVICE_ID);
 					if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
 					{
-						logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): cannot write ERROR_VERSION_MISMATCH",
-							(service == TRUE ? 's': 'c'));
-						cem_add_to_log(logmsg,J_LOG_ERROR);
+						logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): cannot write ERROR_VERSION_MISMATCH to %s/%u",
+							(service == TRUE ? 's': 'c'), ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
+						cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 					}
 					element->connection_state = JAMMO_VERSION_MISMATCH;
-					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): State changed to JAMMO_VERSION_MISMATCH",
-						(service == TRUE ? 's': 'c'));
+					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): State changed to JAMMO_VERSION_MISMATCH for %s/%u",
+						(service == TRUE ? 's': 'c'), ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 				
@@ -452,20 +452,22 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 				gems_message* msg = gems_create_message_service_jammo(VERSION_REPLY);
 				if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),msg) != msg->length)
 				{
-					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): cannot write VERSION_REPLY", (service == TRUE ? 's': 'c'));
-					cem_add_to_log(logmsg,J_LOG_ERROR);
+					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): cannot write VERSION_REPLY to %s/%u", 
+						(service == TRUE ? 's': 'c'), ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
+					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 					success = FALSE;
 				}
 				else
 				{
-					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): wrote bytes: %d [%d|%d|%d|%s]", (service == TRUE ? 's': 'c'),
+					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): wrote bytes: %d [%d|%u|%d|%s]", (service == TRUE ? 's': 'c'),
 						msg->length, ntohs(*(guint16*)&msg->message[0]),ntohl(*(guint32*)&msg->message[2]),ntohs(*(guint16*)&msg->message[6]), &msg->message[8]);
 					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 					
 					element->connection_state = JAMMO_WAITING_REPLY; // Waiting for CONNECT_REPLY
-					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): State changed to JAMMO_WAITING_REPLY", (service == TRUE ? 's': 'c'));
+					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): State changed to JAMMO_WAITING_REPLY for %s/%u",
+						(service == TRUE ? 's': 'c'), ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 				}
@@ -481,7 +483,8 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 				if(service == TRUE)
 				{
 					element->connection_state = JAMMO_CONNECTED_NO_AUTH; // Connected
-					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): State changed to JAMMO_CONNECTED_NO_AUTH", (service == TRUE ? 's': 'c'));
+					logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): State changed to JAMMO_CONNECTED_NO_AUTH for %s/%u",
+						(service == TRUE ? 's': 'c'), ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 				}
@@ -490,20 +493,22 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 					gems_message* msg = gems_create_message_service_jammo(VERSION_REQ);
 					if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),msg) != msg->length)
 					{
-						logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): cannot write VERSION_REQ", (service == TRUE ? 's': 'c'));
-						cem_add_to_log(logmsg,J_LOG_ERROR);
+						logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): cannot write VERSION_REQ to %s/%u",
+							(service == TRUE ? 's': 'c'), ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
+						cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 						success = FALSE;
 					}
 					else
 					{
-						logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): wrote bytes: %d [%d|%d|%d]", (service == TRUE ? 's': 'c'), 
+						logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): wrote bytes: %d [%d|%u|%d]", (service == TRUE ? 's': 'c'), 
 							msg->length, ntohs(*(guint16*)&msg->message[0]),ntohl(*(guint32*)&msg->message[2]),ntohs(*(guint16*)&msg->message[6]));
 						cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 						
 						element->connection_state = JAMMO_WAITING_VERSION; // Waiting for VERSION_REPLY
-						logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): State changed to JAMMO_WAITING_VERSION", (service == TRUE ? 's' : 'c'));
+						logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): State changed to JAMMO_WAITING_VERSION for %s/%u",
+							(service == TRUE ? 's' : 'c'), ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 						cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 					}
@@ -521,16 +526,18 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 	
 	if(wrongstate == TRUE)
 	{
-		logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): invalid command in state: %d",
-			(service == TRUE ? 's': 'c'), element->connection_state);
+		logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): invalid command in state: %d from %s/%u",
+			(service == TRUE ? 's': 'c'), element->connection_state, ph_c_connection_get_remote_address(element->connection), 
+			ph_c_connection_get_device_checksum(element->connection));
 		cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 		g_free(logmsg);
 		
 		gems_message* err = gems_create_error_message(ERROR_INVALID_STATE_TYPE, JAMMO_SERVICE_ID);
 		if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
 		{
-			logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): cannot write ERROR_INVALID_STATE", (service == TRUE ? 's': 'c'));
-			cem_add_to_log(logmsg,J_LOG_ERROR);
+			logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): cannot write ERROR_INVALID_STATE to %s/%u",
+				(service == TRUE ? 's': 'c'), ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
+			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
 		}
 		gems_clear_message(err);
@@ -555,39 +562,45 @@ gboolean gems_service_jammo_process_error(gems_connection *element, gboolean ser
 		switch((errortype = gems_connection_get_16(element, (sizeof(guint16)+sizeof(guint32)+sizeof(guint16)))))
 		{
 			case ERROR_ALREADY_CONNECTED_TYPE:
-				logmsg = g_strdup_printf("gems_service_jammo_process_error: ERROR_ALREADY_CONNECTED");
+				logmsg = g_strdup_printf("gems_service_jammo_process_error: ERROR_ALREADY_CONNECTED from %s/%u", 
+					ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 				cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
 				success = FALSE; // remove this connection in gems_service_jammo_process_list
 				//data->connection_errorlist = gems_connection_error_add(data->connection_errorlist,ph_c_connection_get_device_checksum(element->connection), ERROR_ALREADY_CONNECTED);
 				break;
 			case ERROR_VERSION_MISMATCH_TYPE:
-				logmsg = g_strdup_printf("gems_service_jammo_process_error: ERROR_VERSION_MISMATCH ");
+				logmsg = g_strdup_printf("gems_service_jammo_process_error: ERROR_VERSION_MISMATCH from %s/%u", 
+					ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 				cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
 				element->connection_state = JAMMO_VERSION_MISMATCH; // add to rejected list in gems_service_jammo_process_list
 				break;
 			case ERROR_INVALID_SERVICE_ID_TYPE:
 				// TODO handle this
-				logmsg = g_strdup_printf("gems_service_jammo_process_error: ERROR_INVALID_SERVICE_ID");
+				logmsg = g_strdup_printf("gems_service_jammo_process_error: ERROR_INVALID_SERVICE_ID from %s/%u", 
+					ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 				cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
 				success = FALSE;
 				break;
 			case ERROR_INVALID_STATE_TYPE:
 				// TODO check what is current state - revert to previous state?
-				logmsg = g_strdup_printf("gems_service_jammo_process_error: ERROR_INVALID_STATE");
+				logmsg = g_strdup_printf("gems_service_jammo_process_error: ERROR_INVALID_STATE from %s/%u", 
+					ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 				cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
 				break;
 			case ERROR_CONNECTION_REJECTED_TYPE:
-				logmsg = g_strdup_printf("gems_service_jammo_process_error: ERROR_CONNECTION_REJECTED_TYPE");
+				logmsg = g_strdup_printf("gems_service_jammo_process_error: ERROR_CONNECTION_REJECTED_TYPE from %s/%u", 
+					ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 				cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
 				data->connection_errorlist = gems_connection_error_add(data->connection_errorlist,ph_c_connection_get_device_checksum(element->connection), ERROR_REJECTED);
 				break;
 			default:
-				logmsg = g_strdup_printf("gems_service_jammo_process_error: unexpected error type: %d", errortype);
+				logmsg = g_strdup_printf("gems_service_jammo_process_error: unexpected error type: %d from %s/%u", 
+					errortype, ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 				cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
 				break;
@@ -595,7 +608,9 @@ gboolean gems_service_jammo_process_error(gems_connection *element, gboolean ser
 	}
 	else
 	{
-		logmsg = g_strdup_printf("gems_service_jammo_process_error: unexpected service type: %d", gems_connection_get_16(element, (sizeof(guint16)+sizeof(guint32))));
+		logmsg = g_strdup_printf("gems_service_jammo_process_error: unexpected service type: %d from %s/%u", 
+			gems_connection_get_16(element, (sizeof(guint16)+sizeof(guint32))), 
+			ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 		cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 		g_free(logmsg);
 		// TODO send invalid service id ?
