@@ -26,6 +26,8 @@
 #include "gems_utils.h"
 
 typedef struct {
+	guint8 version;
+	guint8 type;	
 	guint32 userid;
 	gchar* username;
 	gchar* password;
@@ -82,6 +84,7 @@ void gems_teacher_server_clear_profile_data_container(teacher_server_profile_dat
  * gems_teacher_profile_encrypt_profile().
  *
  * Params (duplicates are created from gchars):
+ *  _type  profile type to create, PROF_TYPE_LOCAL or PROF_TYPE_REMOTE (this will be updated to teacher)
  *  _userid - user id to use, should be something else than 0
  *  _username - username
  *  _password - password that user gives
@@ -94,13 +97,14 @@ void gems_teacher_server_clear_profile_data_container(teacher_server_profile_dat
  *  pointer to jammo_profile_container struct when all could be done
  *  NULL if some parameter was not set or the profile couldn't be encrypted
  */
-jammo_profile_container* gems_teacher_server_create_profile(guint32 _userid, gchar* _username, gchar* _password,
+jammo_profile_container* gems_teacher_server_create_profile(guint8 _type, guint32 _userid, gchar* _username, gchar* _password,
 	gchar* _authlevel, gchar* _firstname, gchar* _lastname, guint16 _age, guint32 _avatarid);
 	
 /* Setup a profile with given information, profile will be also encrypted - calls
  * gems_teacher_profile_encrypt_profile().
  *
  * Params (duplicates are created from gchars):
+ *  _type  profile type to create, PROF_TYPE_LOCAL or PROF_TYPE_REMOTE (this will be updated to teacher)
  *  _userid - user id to use, should be something else than 0
  *  _username - username
  *  _password - password that user gives
@@ -115,7 +119,7 @@ jammo_profile_container* gems_teacher_server_create_profile(guint32 _userid, gch
  *  pointer to jammo_profile_container struct when all could be done
  *  NULL if some parameter was not set or the profile couldn't be encrypted
  */
-jammo_profile_container* gems_teacher_server_setup_profile(guint32 _userid, gchar* _username, gchar* _password,
+jammo_profile_container* gems_teacher_server_setup_profile(guint8 _type, guint32 _userid, gchar* _username, gchar* _password,
 	guchar* _salt, gchar* _authlevel, gchar* _firstname, gchar* _lastname, guint16 _age, guint32 _points, guint32 _avatarid);
 
 /* Get a profile from database
@@ -147,7 +151,7 @@ jammo_profile_container* gems_teacher_server_get_profile_for_user_id(teacher_ser
  *  container - pointer to container struct, should have all profile details set!
  * Returns:
  *  TRUE when profile could be encrypted
- *  FALSE if something was missing
+ *  FALSE if something was missing or profile type was not suitable
  */
 gboolean gems_teacher_server_encrypt_profile(jammo_profile_container* container);
 
