@@ -138,7 +138,8 @@ gboolean process_data(gems_connection* c,serverdata* data)
 						}
 						else
 						{
-							c->profile = gems_new_peer_profile(profile->username,profile->userid,profile->age,112);
+							if(c->profile) gems_peer_profile_set_values(c->profile,profile->username,profile->userid,profile->age,profile->avatarid);
+							else c->profile = gems_new_peer_profile(profile->username,profile->userid,profile->age,profile->avatarid);
 							log = g_strdup_printf("Sent profile for username \"%s\"",username);
 							cem_add_to_log(log,J_LOG_INFO);
 							g_free(log);
@@ -237,7 +238,6 @@ gboolean process_data(gems_connection* c,serverdata* data)
 					{
 						// decrypt new pass
 						guchar* decnewpass = gems_security_decrypt_data(recnewencpass,&passlength);
-						guint declength = passlength;
 						
 						gchar* newpass = (gchar*)g_malloc0(sizeof(gchar*)*pwlen);
 						g_memmove(newpass,decnewpass,pwlen);
@@ -269,6 +269,61 @@ gboolean process_data(gems_connection* c,serverdata* data)
 				g_free(rechash);
 				g_free(recnewencpass);
 			}
+			else if (gems_connection_get_16(c,sizeof(gint16)+sizeof(gint32)) == CONTROL_REPLY_LOGIN)
+			{
+				// contains public profile
+				if(gems_connection_get_32(c,sizeof(guint16)) > 8)
+				{
+					guint position = 8;
+					
+					gchar* username = gems_connection_get_char(c,position);
+					position = position + strlen(username) + 1;
+					
+					// User id
+					guint32 uid = gems_connection_get_32(c,position);
+					position = position + sizeof(guint32);
+			
+					
+					guint16 age = gems_connection_get_16(c,position);
+					position = position + sizeof(guint16);
+			
+					
+					guint32 aid = gems_connection_get_32(c,position);
+					
+					log = g_strdup_printf("Got profile, [Id:%u|Name:%s|Age:%d|Avtr:%u]",
+						uid,username,age,aid);
+					cem_add_to_log(log,J_LOG_NETWORK_DEBUG);
+					g_free(log);
+
+					jammo_profile_container* prof = gems_teacher_server_get_profile_for_user_id(data->database,uid);
+					printf("done\n");
+					if(prof)
+					{
+						if(c->profile) gems_peer_profile_set_values(c->profile,prof->username,prof->userid,prof->age,prof->avatarid);
+						else c->profile = gems_new_peer_profile(prof->username,prof->userid,prof->age,prof->avatarid);
+						
+						log = g_strdup_printf("Logged user on device %s/%u is %u:%s, user is in our database.", 
+							ph_c_connection_get_remote_address(c->connection),ph_c_connection_get_device_checksum(c->connection),
+							prof->userid,prof->username);
+						cem_add_to_log(log,J_LOG_INFO);
+						g_free(log);
+					}
+					else
+					{
+						log = g_strdup_printf("Logged user \"%s\" on device %s/%u not found from database.", 
+							username, ph_c_connection_get_remote_address(c->connection),ph_c_connection_get_device_checksum(c->connection));
+						cem_add_to_log(log,J_LOG_INFO);
+						g_free(log);
+					}
+				}
+				else
+				{
+					log = g_strdup_printf("User not logged on device %s/%u .", 
+						ph_c_connection_get_remote_address(c->connection),ph_c_connection_get_device_checksum(c->connection));
+					cem_add_to_log(log,J_LOG_INFO);
+					g_free(log);
+				}
+			}
 			break;
 		case ERROR_MSG:
 			// TODO handle error messages
@@ -295,7 +350,7 @@ void check_connection(gems_connection* c, serverdata* data)
 		// incoming data
 		if(ph_c_connection_has_data(c->connection))
 		{
-			cem_add_to_log("Processing connection: has data", J_LOG_INFO);
+			//cem_add_to_log("Processing connection: has data", J_LOG_INFO);
 			// read service - 16 bits
 			if(gems_connection_partial_data_amount(c) == 0)
 			{
@@ -357,7 +412,7 @@ void check_connection(gems_connection* c, serverdata* data)
 				// All remaining data was read
 				else
 				{
-					cem_add_to_log("All data read!",J_LOG_DEBUG);
+					//cem_add_to_log("All data read!",J_LOG_DEBUG);
 					gems_connection_add_data(c,remainingdata,remaining);
 				}
 			}
@@ -585,7 +640,7 @@ void create_profile_to_database(teacher_server_profile_data* data)
 	do_more = TRUE;*/
 
 	// Create profile
-	jammo_profile_container* profile = gems_teacher_server_create_profile(id,username,password,"none",firstname,lastname,age,avatarid);
+	jammo_profile_container* profile = gems_teacher_server_create_profile(PROF_TYPE_REMOTE,id,username,password,"none",firstname,lastname,age,avatarid);
 	
 	// Profile could be created, add it to list
 	if(profile)
@@ -616,6 +671,8 @@ int main(int argc,char* argv[])
 	
 	configure_init_directories(FALSE);
 	cem_set_log_level(J_LOG_DEBUG+J_LOG_INFO+J_LOG_ERROR+J_LOG_NETWORK_DEBUG);
+	cem_print_also_to_stdout(TRUE);
+	
 	signal(SIGTERM,sighandler);
 	signal(SIGINT,sighandler);
 	
@@ -698,15 +755,15 @@ int main(int argc,char* argv[])
 									}
 									
 									guint32 pnmbr = 0;
-									gchar tmpstr[12];
-									memset(&tmpstr,0,12);
+									gchar tmpstr[50];
+									memset(&tmpstr,0,50);
 									
 									cem_add_to_log("Select a profile (give user id number or the username)",J_LOG_INFO);
 									
 									gems_teacher_server_print_profile_list(data->database->profiles);
 									
 									// Get avatar id
-									if(fgets(tmpstr,12,stdin) == NULL) break;
+									if(fgets(tmpstr,50,stdin) == NULL) break;
 									else
 									{
 										gems_erase_newline(tmpstr);
@@ -737,9 +794,9 @@ int main(int argc,char* argv[])
 										cem_add_to_log(log,J_LOG_INFO);
 										g_free(log);
 									}
-									
+									memset(&tmpstr,0,50);
 									// Get connection number
-									if(fgets(tmpstr,12,stdin) == NULL) break;
+									if(fgets(tmpstr,50,stdin) == NULL) break;
 									else
 									{
 										gems_erase_newline(tmpstr);
@@ -772,6 +829,21 @@ int main(int argc,char* argv[])
 									{
 										gems_communication_write_encrypted_data(JAMMO_PACKET_ADMIN,(gems_connection*)iter->data,msg);
 									}
+									gems_clear_message(msg);
+								}
+								
+								if(g_strcmp0(stdinput,"logins") == 0)
+								{
+									gems_message* msg = gems_create_message_control_get_login();
+									
+									GList* iter = NULL;
+									
+									for(iter = g_list_first(data->clients); iter; iter = g_list_next(iter))
+									{
+										gems_communication_write_encrypted_data(JAMMO_PACKET_ADMIN,(gems_connection*)iter->data,msg);
+									}
+									
+									gems_clear_message(msg);
 								}
 								
 							}
