@@ -28,6 +28,4 @@ void check_connections(serverdata* data);
 void search_clients(serverdata* data);
 teacher_server_profile_data* load_database(teacher_server_profile_data* data);
 void create_profile_to_database(teacher_server_profile_data* data);
-gboolean is_all_integers(gchar* c);
-void erase_newline(gchar* c);
 void save_database(teacher_server_profile_data* data);
